[SCM] Samba Shared Repository - branch master updated

Volker Lendecke vlendec at samba.org
Thu Apr 27 15:28:01 UTC 2023


The branch, master has been updated
       via  dc96e9cfd5d libcli:smb: Fix code spelling
       via  e38f7cf4f19 libcli:security: Fix code spelling
       via  fc7d58ee394 libcli:ldap: Fix code spelling
       via  e3a710f2906 libcli:drsuapi: Fix code spelling
       via  adcc92f8359 libcli:auth: Fix code spelling
      from  6490ff63552 s3:lib: Give better warnings about corrupted AppleDobule files

https://git.samba.org/?p=samba.git;a=shortlog;h=master


- Log -----------------------------------------------------------------
commit dc96e9cfd5dad8e4586ef6214214f225fdf852c2
Author: Andreas Schneider <asn at samba.org>
Date:   Thu Apr 27 15:58:18 2023 +0200

    libcli:smb: Fix code spelling
    
    Signed-off-by: Andreas Schneider <asn at samba.org>
    Reviewed-by: Volker Lendecke <vl at samba.org>
    
    Autobuild-User(master): Volker Lendecke <vl at samba.org>
    Autobuild-Date(master): Thu Apr 27 15:27:21 UTC 2023 on atb-devel-224

commit e38f7cf4f19c545d8fa31bed237427942311480d
Author: Andreas Schneider <asn at samba.org>
Date:   Thu Apr 27 15:56:42 2023 +0200

    libcli:security: Fix code spelling
    
    Signed-off-by: Andreas Schneider <asn at samba.org>
    Reviewed-by: Volker Lendecke <vl at samba.org>

commit fc7d58ee39449201304771dd628b220e2578858a
Author: Andreas Schneider <asn at samba.org>
Date:   Thu Apr 27 15:54:54 2023 +0200

    libcli:ldap: Fix code spelling
    
    Signed-off-by: Andreas Schneider <asn at samba.org>
    Reviewed-by: Volker Lendecke <vl at samba.org>

commit e3a710f2906ec263aa87807c9ac1118307f69580
Author: Andreas Schneider <asn at samba.org>
Date:   Thu Apr 27 15:54:15 2023 +0200

    libcli:drsuapi: Fix code spelling
    
    Signed-off-by: Andreas Schneider <asn at samba.org>
    Reviewed-by: Volker Lendecke <vl at samba.org>

commit adcc92f83594abc3ab98fd0f138cdc76d3d2560d
Author: Andreas Schneider <asn at samba.org>
Date:   Thu Apr 27 15:53:25 2023 +0200

    libcli:auth: Fix code spelling
    
    Signed-off-by: Andreas Schneider <asn at samba.org>
    Reviewed-by: Volker Lendecke <vl at samba.org>

-----------------------------------------------------------------------

Summary of changes:
 libcli/auth/msrpc_parse.c             | 2 +-
 libcli/auth/proto.h                   | 2 +-
 libcli/auth/schannel_state_tdb.c      | 4 ++--
 libcli/auth/session.c                 | 8 ++++----
 libcli/auth/smbencrypt.c              | 2 +-
 libcli/drsuapi/repl_decrypt.c         | 4 ++--
 libcli/ldap/tests/ldap_message_test.c | 4 ++--
 libcli/security/access_check.c        | 2 +-
 libcli/security/create_descriptor.c   | 2 +-
 libcli/security/object_tree.c         | 2 +-
 libcli/security/privileges.c          | 4 ++--
 libcli/security/privileges.h          | 2 +-
 libcli/security/security.h            | 2 +-
 libcli/security/security_descriptor.c | 2 +-
 libcli/security/util_sid.c            | 2 +-
 libcli/smb/smb1cli_close.c            | 4 ++--
 libcli/smb/smb1cli_create.c           | 8 ++++----
 libcli/smb/smb1cli_read.c             | 4 ++--
 libcli/smb/smb1cli_write.c            | 8 ++++----
 libcli/smb/smbXcli_base.c             | 6 +++---
 libcli/smb/smb_constants.h            | 6 +++---
 libcli/smb/smb_signing.c              | 6 +++---
 libcli/smb/tstream_smbXcli_np.c       | 2 +-
 libcli/smb/util.c                     | 6 +++---
 24 files changed, 47 insertions(+), 47 deletions(-)


Changeset truncated at 500 lines:

diff --git a/libcli/auth/msrpc_parse.c b/libcli/auth/msrpc_parse.c
index 86ba2ec00d4..8326261e838 100644
--- a/libcli/auth/msrpc_parse.c
+++ b/libcli/auth/msrpc_parse.c
@@ -24,7 +24,7 @@
 
 /*
   this is a tiny msrpc packet generator. I am only using this to
-  avoid tying this code to a particular varient of our rpc code. This
+  avoid tying this code to a particular variant of our rpc code. This
   generator is not general enough for all our rpc needs, its just
   enough for the spnego/ntlmssp code
 
diff --git a/libcli/auth/proto.h b/libcli/auth/proto.h
index f6ca2f1632d..b202542068d 100644
--- a/libcli/auth/proto.h
+++ b/libcli/auth/proto.h
@@ -224,7 +224,7 @@ bool extract_pwd_blob_from_buffer514(TALLOC_CTX *mem_ctx,
 /**
  * @brief Decode AES password buffer to password in the given charset.
  *
- * @param mem_ctx       The memory context to allocate the deocded passwrod on.
+ * @param mem_ctx       The memory context to allocate the decoded password on.
  *
  * @param in_buffer[514] The in buffer with the decrypted password data.
  *
diff --git a/libcli/auth/schannel_state_tdb.c b/libcli/auth/schannel_state_tdb.c
index e0ac8a378a0..ac3654e2c99 100644
--- a/libcli/auth/schannel_state_tdb.c
+++ b/libcli/auth/schannel_state_tdb.c
@@ -34,7 +34,7 @@
 
 /******************************************************************************
  Open or create the schannel session store tdb.  Non-static so it can
- be called from parent processes to corectly handle TDB_CLEAR_IF_FIRST
+ be called from parent processes to correctly handle TDB_CLEAR_IF_FIRST
 *******************************************************************************/
 
 struct db_context *open_schannel_session_store(TALLOC_CTX *mem_ctx,
@@ -550,7 +550,7 @@ NTSTATUS schannel_save_challenge(struct loadparm_context *lp_ctx,
  remote machine stored in the schannel database.
 
  The credentials are (re)read and from the schannel database, and
- written back after the caclulations are performed.
+ written back after the calculations are performed.
 
  If the creds_out parameter is not NULL returns the credentials.
  ********************************************************************/
diff --git a/libcli/auth/session.c b/libcli/auth/session.c
index 43ce9d54fdc..dba6c5c5b49 100644
--- a/libcli/auth/session.c
+++ b/libcli/auth/session.c
@@ -131,7 +131,7 @@ char *sess_decrypt_string(TALLOC_CTX *mem_ctx,
 	}
 
 	if (IVAL(out.data, 4) != 1) {
-		DEBUG(0,("Unexpected revision number %d in session crypted string\n",
+		DEBUG(0,("Unexpected revision number %d in session encrypted string\n",
 			 IVAL(out.data, 4)));
 		data_blob_free(&out);
 		return NULL;
@@ -204,7 +204,7 @@ NTSTATUS sess_decrypt_blob(TALLOC_CTX *mem_ctx, const DATA_BLOB *blob, const DAT
 	int rc, slen;
 
 	if (blob->length < 8) {
-		DEBUG(0, ("Unexpected length %d in session crypted secret (BLOB)\n",
+		DEBUG(0, ("Unexpected length %d in session encrypted secret (BLOB)\n",
 			  (int)blob->length));
 		return NT_STATUS_INVALID_PARAMETER;
 	}
@@ -221,14 +221,14 @@ NTSTATUS sess_decrypt_blob(TALLOC_CTX *mem_ctx, const DATA_BLOB *blob, const DAT
 	}
 
 	if (IVAL(out.data, 4) != 1) {
-		DEBUG(2,("Unexpected revision number %d in session crypted secret (BLOB)\n",
+		DEBUG(2,("Unexpected revision number %d in session encrypted secret (BLOB)\n",
 			 IVAL(out.data, 4)));
 		return NT_STATUS_UNKNOWN_REVISION;
 	}
 		
 	slen = IVAL(out.data, 0);
 	if (slen > blob->length - 8) {
-		DEBUG(0,("Invalid crypt length %d in session crypted secret (BLOB)\n", slen));
+		DEBUG(0,("Invalid crypt length %d in session encrypted secret (BLOB)\n", slen));
 		return NT_STATUS_WRONG_PASSWORD;
 	}
 
diff --git a/libcli/auth/smbencrypt.c b/libcli/auth/smbencrypt.c
index 8492202ea93..d525b373e86 100644
--- a/libcli/auth/smbencrypt.c
+++ b/libcli/auth/smbencrypt.c
@@ -1105,7 +1105,7 @@ NTSTATUS encode_rc4_passwd_buffer(const char *passwd,
 
 	/*
 	 * The packet format is the 516 byte RC4 encrypted
-	 * pasword followed by the 16 byte counfounder
+	 * password followed by the 16 byte counfounder
 	 * The confounder is a salt to prevent pre-computed hash attacks on the
 	 * database.
 	 */
diff --git a/libcli/drsuapi/repl_decrypt.c b/libcli/drsuapi/repl_decrypt.c
index 30b3c64379f..d28924603ab 100644
--- a/libcli/drsuapi/repl_decrypt.c
+++ b/libcli/drsuapi/repl_decrypt.c
@@ -115,7 +115,7 @@ static WERROR drsuapi_decrypt_attribute_value(TALLOC_CTX *mem_ctx,
 	}
 	/*
 	 * The following rid_crypt obfuscation isn't session specific
-	 * and not really needed here, because we allways know the rid of the
+	 * and not really needed here, because we always know the rid of the
 	 * user account.
 	 *
 	 * some attributes with this 'additional encryption' include
@@ -240,7 +240,7 @@ static WERROR drsuapi_encrypt_attribute_value(TALLOC_CTX *mem_ctx,
 
 	/*
 	 * The following rid_crypt obfuscation isn't session specific
-	 * and not really needed here, because we allways know the rid of the
+	 * and not really needed here, because we always know the rid of the
 	 * user account.
 	 *
 	 * some attributes with this 'additional encryption' include
diff --git a/libcli/ldap/tests/ldap_message_test.c b/libcli/ldap/tests/ldap_message_test.c
index 4050b7f1cb1..bea7b911846 100644
--- a/libcli/ldap/tests/ldap_message_test.c
+++ b/libcli/ldap/tests/ldap_message_test.c
@@ -50,7 +50,7 @@
 void cm_print_error(const char * const format, ...);
 /*
  * helper function and macro to compare an ldap error code constant with the
- * coresponding nt_status code
+ * corresponding nt_status code
  */
 #define NT_STATUS_LDAP_V(code) (0xF2000000 | code)
 static void _assert_ldap_status_equal(
@@ -159,7 +159,7 @@ static void test_recursion_depth_large(void **state)
 
 
 	/*
-	 * Load a test data file containg 10,000 or clauses in encoded as
+	 * Load a test data file containing 10,000 or clauses in encoded as
 	 * an ASN.1 packet.
 	 */
 	buffer = talloc_zero_array(test_ctx, uint8_t, BUFF_SIZE);
diff --git a/libcli/security/access_check.c b/libcli/security/access_check.c
index fce8bc30dad..81bacc90e78 100644
--- a/libcli/security/access_check.c
+++ b/libcli/security/access_check.c
@@ -644,7 +644,7 @@ done:
  * Perform DS access checks for the user represented by its security_token, on
  * the provided security descriptor. If an tree associating GUID and access
  * required is provided then object access (OA) are checked as well. *
- * @param[in]   sd             The security descritor against which the required
+ * @param[in]   sd             The security descriptor against which the required
  *                             access are requested
  *
  * @param[in]   token          The security_token associated with the user to
diff --git a/libcli/security/create_descriptor.c b/libcli/security/create_descriptor.c
index ccb32593ecb..3d9672f5c6a 100644
--- a/libcli/security/create_descriptor.c
+++ b/libcli/security/create_descriptor.c
@@ -304,7 +304,7 @@ static struct security_acl *calculate_inherited_from_parent(TALLOC_CTX *mem_ctx,
 			/*
 			 * If the ACE had an explicit object class
 			 * schemaId, but no attribute/propertySet
-			 * we need to downgrate the _OBJECT variants
+			 * we need to downgrade the _OBJECT variants
 			 * to the normal ones.
 			 */
 			if (inherited_property == NULL) {
diff --git a/libcli/security/object_tree.c b/libcli/security/object_tree.c
index c1025e766f6..70b1ea06927 100644
--- a/libcli/security/object_tree.c
+++ b/libcli/security/object_tree.c
@@ -24,7 +24,7 @@
  *               the object tree that must be constructed to perform access checks.
  *               The object tree is an unbalanced tree of depth 3, indexed by
  *               object type guid. Perhaps a different data structure
- *               should be concidered later to improve performance
+ *               should be considered later to improve performance
  *
  *  Author: Nadezhda Ivanova
  */
diff --git a/libcli/security/privileges.h b/libcli/security/privileges.h
index c8a8dadd630..2224543d25a 100644
--- a/libcli/security/privileges.h
+++ b/libcli/security/privileges.h
@@ -49,7 +49,7 @@ typedef struct {
 const char* get_privilege_dispname( const char *name );
 
 /*******************************************************************
- return the number of elements in the 'short' privlege array (traditional source3 behaviour)
+ return the number of elements in the 'short' privilege array (traditional source3 behaviour)
 *******************************************************************/
 
 int num_privileges_in_short_list( void );
diff --git a/libcli/security/security.h b/libcli/security/security.h
index 4df18eba535..7c214bd3c1e 100644
--- a/libcli/security/security.h
+++ b/libcli/security/security.h
@@ -97,7 +97,7 @@
  * to be granted in order to fulfill the requested access.
  *
  * The GUID is optional, if specified it restricts this object tree and its
- * childs to object/attributes that inherits from this GUID.
+ * children to object/attributes that inherits from this GUID.
  * For DS access an object inherits from a GUID if one of its class has this GUID
  * in the schemaIDGUID attribute.
  */
diff --git a/libcli/security/security_descriptor.c b/libcli/security/security_descriptor.c
index ebc5c8f1f45..ba7445832cd 100644
--- a/libcli/security/security_descriptor.c
+++ b/libcli/security/security_descriptor.c
@@ -226,7 +226,7 @@ NTSTATUS security_descriptor_for_client(TALLOC_CTX *mem_ctx,
 	}
 
 	/*
-	 * ... and remove everthing not wanted
+	 * ... and remove everything not wanted
 	 */
 
 	if (!(sec_info & SECINFO_OWNER)) {
diff --git a/libcli/security/util_sid.c b/libcli/security/util_sid.c
index 30ac56789a5..0a8e114c338 100644
--- a/libcli/security/util_sid.c
+++ b/libcli/security/util_sid.c
@@ -66,7 +66,7 @@ const struct dom_sid global_sid_Authenticated_Users =	/* All authenticated rids
 { 1, 1, {0,0,0,0,0,5}, {11,0,0,0,0,0,0,0,0,0,0,0,0,0,0}};
 #if 0
 /* for documentation S-1-5-12 */
-const struct dom_sid global_sid_Restriced =			/* Restriced Code */
+const struct dom_sid global_sid_Restriced =			/* Restricted Code */
 { 1, 1, {0,0,0,0,0,5}, {12,0,0,0,0,0,0,0,0,0,0,0,0,0,0}};
 #endif
 
diff --git a/libcli/smb/smb1cli_close.c b/libcli/smb/smb1cli_close.c
index 89fbbba83f5..00baa58457e 100644
--- a/libcli/smb/smb1cli_close.c
+++ b/libcli/smb/smb1cli_close.c
@@ -38,7 +38,7 @@ static void smb1cli_close_done(struct tevent_req *subreq);
  * @param[in] mem_ctx  The memory context for the result.
  * @param[in] ev The event context to work on.
  * @param[in] conn The smb connection.
- * @param[in] timeout_msec If positiv a timeout for the request.
+ * @param[in] timeout_msec If positive a timeout for the request.
  * @param[in] pid The process identifier.
  * @param[in] tcon The smb tree connect.
  * @param[in] session The smb session.
@@ -133,7 +133,7 @@ NTSTATUS smb1cli_close_recv(struct tevent_req *req)
  * @see smb1cli_close_send(), smb1cli_close_recv()
  *
  * @param[in] conn The smb connection.
- * @param[in] timeout_msec If positiv a timeout for the request.
+ * @param[in] timeout_msec If positive a timeout for the request.
  * @param[in] pid The process identifier.
  * @param[in] tcon The smb tree connect.
  * @param[in] session The smb session.
diff --git a/libcli/smb/smb1cli_create.c b/libcli/smb/smb1cli_create.c
index d9887a04cda..fc1e16b2be1 100644
--- a/libcli/smb/smb1cli_create.c
+++ b/libcli/smb/smb1cli_create.c
@@ -39,7 +39,7 @@ static void smb1cli_ntcreatex_done(struct tevent_req *subreq);
  * @param[in] mem_ctx The memory context for the result.
  * @param[in] ev The event context to work on.
  * @param[in] conn The smb connection.
- * @param[in] timeout_msec If positiv a timeout for the request.
+ * @param[in] timeout_msec If positive a timeout for the request.
  * @param[in] pid The process identifier
  * @param[in] tcon The smb tree connect.
  * @param[in] session The smb session.
@@ -189,7 +189,7 @@ static void smb1cli_ntcreatex_done(struct tevent_req *subreq)
  * @param[in] req A tevent request created with smb1cli_ntcreatex_send()
  * @param[out] pfnum The file id of the opened file or directory.
  *
- * @return NT_STATUS_OK on succsess
+ * @return NT_STATUS_OK on success
  */
 NTSTATUS smb1cli_ntcreatex_recv(struct tevent_req *req, uint16_t *pfnum)
 {
@@ -214,7 +214,7 @@ NTSTATUS smb1cli_ntcreatex_recv(struct tevent_req *req, uint16_t *pfnum)
  * @see smb1cli_ntcreatex_send() smb1cli_ntcreatex_recv()
  *
  * @param[in] conn The smb connection.
- * @param[in] timeout_msec If positiv a timeout for the request.
+ * @param[in] timeout_msec If positive a timeout for the request.
  * @param[in] pid The process identifier
  * @param[in] tcon The smb tree connect.
  * @param[in] session The smb session.
@@ -231,7 +231,7 @@ NTSTATUS smb1cli_ntcreatex_recv(struct tevent_req *req, uint16_t *pfnum)
  * @param[in] SecurityFlags
  * @param[out] pfnum The file id representing the file or directory created or opened.
  *
- * @return  NT_STATUS_OK on succsess
+ * @return  NT_STATUS_OK on success
  */
 NTSTATUS smb1cli_ntcreatex(struct smbXcli_conn *conn,
 			   uint32_t timeout_msec,
diff --git a/libcli/smb/smb1cli_read.c b/libcli/smb/smb1cli_read.c
index d7a7f43e66e..877aab530da 100644
--- a/libcli/smb/smb1cli_read.c
+++ b/libcli/smb/smb1cli_read.c
@@ -43,7 +43,7 @@ static void smb1cli_readx_done(struct tevent_req *subreq);
  * @param[in] mem_ctx The memory context for the result.
  * @param[in] ev The event context to work on.
  * @param[in] conn The smb connection.
- * @param[in] timeout_msec If positiv a timeout for the request.
+ * @param[in] timeout_msec If positive a timeout for the request.
  * @param[in] pid The process identifier
  * @param[in] tcon The smb tree connect.
  * @param[in] session The smb session.
@@ -220,7 +220,7 @@ static void smb1cli_readx_done(struct tevent_req *subreq)
  * @param[out] received The number of bytes received.
  * @param[out] rcvbuf Pointer to the bytes received.
  *
- * @return NT_STATUS_OK or STATUS_BUFFER_OVERFLOW on succsess.
+ * @return NT_STATUS_OK or STATUS_BUFFER_OVERFLOW on success.
  */
 NTSTATUS smb1cli_readx_recv(struct tevent_req *req,
 			    uint32_t *received,
diff --git a/libcli/smb/smb1cli_write.c b/libcli/smb/smb1cli_write.c
index 66f93c0cdfa..d5bc57aa816 100644
--- a/libcli/smb/smb1cli_write.c
+++ b/libcli/smb/smb1cli_write.c
@@ -42,7 +42,7 @@ static void smb1cli_writex_done(struct tevent_req *subreq);
  * @param[in] mem_ctx The memory context for the result.
  * @param[in] ev The event context to work on.
  * @param[in] conn The smb connection.
- * @param[in] timeout_msec If positiv a timeout for the request.
+ * @param[in] timeout_msec If positive a timeout for the request.
  * @param[in] pid The process identifier
  * @param[in] tcon The smb tree connect.
  * @param[in] session The smb session.
@@ -190,7 +190,7 @@ static void smb1cli_writex_done(struct tevent_req *subreq)
  * @param[out] pwritten The number of bytes written to the file.
  * @param[out] pavailable Valid if writing to a named pipe or IO device.
  *
- * @return NT_STATUS_OK on succsess.
+ * @return NT_STATUS_OK on success.
  */
 NTSTATUS smb1cli_writex_recv(struct tevent_req *req, uint32_t *pwritten, uint16_t *pavailable)
 {
@@ -216,7 +216,7 @@ NTSTATUS smb1cli_writex_recv(struct tevent_req *req, uint32_t *pwritten, uint16_
  * @see smb1cli_writex_send(), smb1cli_writex_recv()
  *
  * @param[in] conn The smb connection.
- * @param[in] timeout_msec If positiv a timeout for the request.
+ * @param[in] timeout_msec If positive a timeout for the request.
  * @param[in] pid The process identifier
  * @param[in] tcon The smb tree connect.
  * @param[in] session The smb session.
@@ -228,7 +228,7 @@ NTSTATUS smb1cli_writex_recv(struct tevent_req *req, uint32_t *pwritten, uint16_
  * @param[out] pwritten The number of bytes written to the file.
  * @param[out] pavailable Valid if writing to a named pipe or IO device.
  *
- * @return NT_STATUS_OK on succsess.
+ * @return NT_STATUS_OK on success.
  */
 NTSTATUS smb1cli_writex(struct smbXcli_conn *conn,
 			uint32_t timeout_msec,
diff --git a/libcli/smb/smbXcli_base.c b/libcli/smb/smbXcli_base.c
index a2a551d0f79..fe422eb83fa 100644
--- a/libcli/smb/smbXcli_base.c
+++ b/libcli/smb/smbXcli_base.c
@@ -3226,7 +3226,7 @@ NTSTATUS smb2cli_req_compound_submit(struct tevent_req **reqs,
 		 * nonce wrap, or the security of the whole
 		 * communication and the keys is destroyed.
 		 * We must drop the connection once we have
-		 * transfered too much data.
+		 * transferred too much data.
 		 *
 		 * NOTE: We assume nonces greater than 8 bytes.
 		 */
@@ -3888,7 +3888,7 @@ static NTSTATUS smb2cli_conn_dispatch_incoming(struct smbXcli_conn *conn,
 			if (!NT_STATUS_IS_OK(status)) {
 				/*
 				 * Only check the signature of the last response
-				 * of a successfull session auth. This matches
+				 * of a successful session auth. This matches
 				 * Windows behaviour for NTLM auth and reauth.
 				 */
 				state->smb2.require_signed_response = false;
@@ -6540,7 +6540,7 @@ NTSTATUS smb2cli_session_set_session_key(struct smbXcli_session *session,
 	 * nonce wrap, or the security of the whole
 	 * communication and the keys is destroyed.
 	 * We must drop the connection once we have
-	 * transfered too much data.
+	 * transferred too much data.
 	 *
 	 * NOTE: We assume nonces greater than 8 bytes.
 	 */
diff --git a/libcli/smb/smb_constants.h b/libcli/smb/smb_constants.h
index a08b1931277..1ee5d7f406e 100644
--- a/libcli/smb/smb_constants.h
+++ b/libcli/smb/smb_constants.h
@@ -27,8 +27,8 @@
  */
 #define NBSSmessage     0x00   /* session message */
 #define NBSSrequest     0x81   /* session request */
-#define NBSSpositive    0x82   /* positiv session response */
-#define NBSSnegative    0x83   /* negativ session response */
+#define NBSSpositive    0x82   /* positive session response */
+#define NBSSnegative    0x83   /* negative session response */
 #define NBSSretarget    0x84   /* retarget session response */
 #define NBSSkeepalive   0x85   /* keepalive */
 
@@ -400,7 +400,7 @@ enum csc_policy {
 #define FILE_CASE_PRESERVED_NAMES       0x00000002
 #define FILE_UNICODE_ON_DISK            0x00000004
 /* According to cifs9f, this is 4, not 8 */
-/* Acconding to testing, this actually sets the security attribute! */
+/* According to testing, this actually sets the security attribute! */
 #define FILE_PERSISTENT_ACLS            0x00000008
 #define FILE_FILE_COMPRESSION           0x00000010
 #define FILE_VOLUME_QUOTAS              0x00000020
diff --git a/libcli/smb/smb_signing.c b/libcli/smb/smb_signing.c
index 1d768ef39d0..d50c9638380 100644
--- a/libcli/smb/smb_signing.c
+++ b/libcli/smb/smb_signing.c
@@ -30,13 +30,13 @@
 /* Used by the SMB1 signing functions. */
 
 struct smb1_signing_state {
-	/* is signing localy allowed */
+	/* is signing locally allowed */
 	bool allowed;
 
-	/* is signing localy desired */
+	/* is signing locally desired */
 	bool desired;
 
-	/* is signing localy mandatory */
+	/* is signing locally mandatory */
 	bool mandatory;
 
 	/* is signing negotiated by the peer */
diff --git a/libcli/smb/tstream_smbXcli_np.c b/libcli/smb/tstream_smbXcli_np.c
index ef685e16f4f..990673196a8 100644
--- a/libcli/smb/tstream_smbXcli_np.c
+++ b/libcli/smb/tstream_smbXcli_np.c
@@ -112,7 +112,7 @@ static int tstream_smbXcli_np_destructor(struct tstream_smbXcli_np *cli_nps)
 	 * tstream_disconnect_send()/_recv(), this will
 	 * never be called.
 	 *
-	 * We use a maximun timeout of 1 second == 1000 msec.
+	 * We use a maximum timeout of 1 second == 1000 msec.
 	 */
 	cli_nps->timeout = MIN(cli_nps->timeout, 1000);
 
diff --git a/libcli/smb/util.c b/libcli/smb/util.c
index c7b51ff84db..6e29a98dc40 100644
--- a/libcli/smb/util.c
+++ b/libcli/smb/util.c
@@ -212,7 +212,7 @@ bool smb_buffer_oob(uint32_t bufsize, uint32_t offset, uint32_t length)
 }
 
 /***********************************************************
- Common function for pushing stings, used by smb_bytes_push_str()
+ Common function for pushing strings, used by smb_bytes_push_str()
  and trans_bytes_push_str(). Only difference is the align_odd
  parameter setting.
 ***********************************************************/
@@ -431,7 +431,7 @@ NTSTATUS smb_bytes_pull_str(TALLOC_CTX *mem_ctx, char **_str, bool ucs2,
  *
  * @param[in]  str  The string to translate.
  *
- * @return A corresponding enum @smb_signing_setting tranlated from the string.
+ * @return A corresponding enum @smb_signing_setting translated from the string.
  */
 enum smb_signing_setting smb_signing_setting_translate(const char *str)
 {
@@ -450,7 +450,7 @@ enum smb_signing_setting smb_signing_setting_translate(const char *str)
  *
  * @param[in]  str  The string to translate.
  *
- * @return A corresponding enum @smb_encryption_setting tranlated from the
+ * @return A corresponding enum @smb_encryption_setting translated from the
  *         string.
  */


diff --git a/libcli/security/privileges.c b/libcli/security/privileges.c
index 7910001c60d..acaf0b0fbc0 100644
--- a/libcli/security/privileges.c
+++ b/libcli/security/privileges.c
@@ -234,7 +234,7 @@ const char* get_privilege_dispname( const char *name )
 }
 
 /*******************************************************************
- return the number of elements in the 'short' privlege array (traditional source3 behaviour)
+ return the number of elements in the 'short' privilege array (traditional source3 behaviour)
 *******************************************************************/
 
 int num_privileges_in_short_list( void )
@@ -442,7 +442,7 @@ bool security_token_system_privilege(const struct security_token *token)
 */
 void security_token_set_privilege(struct security_token *token, enum sec_privilege privilege)
 {
 	/* Relies on the fact that an invalid privilage will return 0, so won't change this */
 	token->privilege_mask |= sec_privilege_mask(privilege);
 }
 
@@ -442,7 +442,7 @@ bool security_token_system_privilege(const struct security_token *token)
 void security_token_set_privilege(struct security_token *token, enum sec_privilege privilege)
 {
-	/* Relies on the fact that an invalid privilage will return 0, so won't change this */
+	/* Relies on the fact that an invalid privilege will return 0, so won't change this */
 	token->privilege_mask |= sec_privilege_mask(privilege);
 }
-- 
Samba Shared Repository



More information about the samba-cvs mailing list